OC.L10N.register(
    "files",
    {
    "File could not be found" : "پرونده پیدا نشد",
    "Move or copy" : "انتقال یا رونوشت",
    "Download" : "دانلود",
    "Delete" : "حذف",
    "Tags" : "برچسب‌ها",
    "Show list view" : "نمایش فهرستی",
    "Show grid view" : "نمایش شبکه‌ای",
    "Home" : "خانه",
    "Close" : "بستن",
    "Could not create folder \"{dir}\"" : "پوشهٔ \"{dir}\" ساخته نشد",
    "This will stop your current uploads." : "با این کار بارگذاری فعلی شما متوقف خواهد شد.",
    "Upload cancelled." : "بار گذاری لغو شد",
    "Processing files …" : "پردازش پرونده‌ها...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "امکان آپلود {filename} وجود ندارد، پوشه‌ای با این نام یا فایلی با حجم 0 بایت با این نام وجود دارد",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "ظرفیت لازم وجود ندارد، شما آپلودی با حجم {size1}  را انجام میدهید اما تنها {size2} فضا باقی مانده است",
    "Target folder \"{dir}\" does not exist any more" : "پوشه هدف \"{dir}\" دیگر وجود ندارد",
    "Not enough free space" : "فضای کافی در دسترس نیست",
    "An unknown error has occurred" : "خطایی ناشناخته اتفاق افتاده است",
    "File could not be uploaded" : "پرونده بارگذاری نشد",
    "Uploading …" : "بارگذاری...",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "در حال بارگذاری ... ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} از {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "بارگذاری آن مورد پشتیبانی نمی‌شود",
    "Target folder does not exist any more" : "پوشه هدف وجود ندارد",
    "Operation is blocked by access control" : "مدیریت دسترسی، عملیات را متوقف کرد",
    "Error when assembling chunks, status code {status}" : "خطا هنگام جمع آوری قطعه ها، کد وضعیت {status}",
    "Actions" : "فعالیت ها",
    "Rename" : "تغییرنام",
    "Move" : "انتقال",
    "Copy" : "رونوشت",
    "Choose target folder" : "پوشهٔ هدف را انتخاب کنید",
    "Set reminder" : "Set reminder",
    "Edit locally" : "ویرایش محلی",
    "Open" : "باز کردن",
    "Delete file" : "حذف پرونده",
    "Delete folder" : "حذف پوشه",
    "Disconnect storage" : "فضای ذخیره را جدا کنید",
    "Leave this share" : "ترک این اشتراک",
    "Could not load info for file \"{file}\"" : "بارگیری اطلاعات برای پرونده امکان پذیر نیست \"{file}\"",
    "Files" : "پرونده‌ها",
    "Details" : "جزئیات",
    "Please select tag(s) to add to the selection" : "لطفاً برچسب(های) را برای افزودن به انتخاب انتخاب کنید",
    "Apply tag(s) to selection" : "تگ(ها) را در انتخاب اعمال کنید",
    "Select directory \"{dirName}\"" : "دایرکتوری \"{dirName}\" را انتخاب کنید",
    "Select file \"{fileName}\"" : "فایل \"{fileName}\" را انتخاب کنید",
    "Pending" : "در انتظار",
    "Unable to determine date" : "امکان تعیین تاریخ وجود ندارد",
    "This operation is forbidden" : "این عملیات غیرمجاز است",
    "This directory is unavailable, please check the logs or contact the administrator" : "پوشه‌ در دسترس نیست، لطفا لاگ‌ها را بررسی کنید یا به مدیر سیستم اطلاع دهید",
    "Storage is temporarily not available" : "ذخیره سازی به طور موقت در دسترس نیست",
    "Could not move \"{file}\", target exists" : "انتقال\"{پرونده}\" امکان پذیر نیست ، هدف وجود دارد",
    "Could not move \"{file}\"" : "پروندهٔ \"{file}\" منتقل نمی‌شود",
    "copy" : "کپی",
    "Could not copy \"{file}\", target exists" : "\"{پرونده}\" کپی نشد ، هدف وجود دارد",
    "Could not copy \"{file}\"" : "پرونده کپی نشد",
    "Copied {origin} inside {destination}" : "کپی شده (اصل) در مقصد",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "رونوشت شده از {origin} و {nbfiles} پرونده‌های دیگر در {destination}",
    "Failed to redirect to client" : "هدایت به مشتری انجام نشد",
    "{newName} already exists" : "{newName} قبلاً موجود است",
    "Could not rename \"{fileName}\", it does not exist any more" : "نمی‌توان نام «{fileName}» را تغییر داد، دیگر وجود ندارد",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "عنوان \"{targetName}\" هم اکنون در پوشه \"{dir}\" وجود دارد. لطفا نام دیگری انتخاب کنید",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" تغییر نام داده نمی‌شود",
    "Could not create file \"{file}\"" : "پروندهٔ \"{file}\" ساخته نشد",
    "Could not create file \"{file}\" because it already exists" : "نمی توان پرونده \"{file}\" ایجاد کرد زیرا در حال حاضر وجود دارد",
    "Could not create folder \"{dir}\" because it already exists" : "شاخه \"{dir}\" به علت موجود بودن ساخته نشد",
    "Could not fetch file details \"{file}\"" : "جزئیات فایل \"{file}\" واکشی نشد",
    "Error deleting file \"{fileName}\"." : "خطای حذف پروندهٔ \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "جستجو در پوشه های دیگر برای {tag}{filter}{endtag} یافت نشد",
    "Enter more than two characters to search in other folders" : "برای جستجو در پوشه های دیگر بیش از دو کاراکتر وارد کنید",
    "Name" : "نام",
    "Size" : "اندازه",
    "Modified" : "تاریخ",
    "_%n folder_::_%n folders_" : ["%n پوشه","%n پوشه"],
    "_%n file_::_%n files_" : ["%n فایل","%n فایل"],
    "{dirs} and {files}" : "{dirs} و {files}",
    "_including %n hidden_::_including %n hidden_" : ["از جمله %nپنهان","از جمله %nپنهان"],
    "You do not have permission to upload or create files here" : "شما اجازه آپلود یا ایجاد فایل در اینجا را ندارید",
    "_Uploading %n file_::_Uploading %n files_" : ["در حال بارگذاری %n فایل","در حال بارگذاری %n فایل"],
    "New" : "جدید",
    "New file/folder menu" : "منوی فایل/پوشه جدید",
    "Select file range" : "محدوده فایل را انتخاب کنید",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "{used} از {quota} استفاده شده",
    "{used} used" : "{used} استفاده شده",
    "\"{name}\" is an invalid file name." : "\"{name}\" نامی نامعتبر برای فایل است.",
    "File name cannot be empty." : "نام پرونده نمی تواند خالی باشد.",
    "\"/\" is not allowed inside a file name." : "\"/\" در داخل نام فایل مجاز نیست.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" یک نوع پرونده مجاز نیست",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "فضای ذخیره‌سازی {owner} پر است، فایل‌ها دیگر نمی‌توانند به‌روزرسانی یا همگام‌سازی شوند!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "پوشه گروه \"{mountPoint}\" پر است، فایل‌ها دیگر قابل به‌روزرسانی یا همگام‌سازی نیستند!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "حافظه خارجی \"{mountPoint}\" پر است، فایل‌ها دیگر نمی‌توانند به‌روزرسانی یا همگام‌سازی شوند!",
    "Your storage is full, files cannot be updated or synced anymore!" : "فضای ذخیره‌سازی شما پر است، فایل‌ها دیگر نمی‌توانند به‌روزرسانی یا همگام‌سازی شوند!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "فضای ذخیره سازی {owner} تقریباً پر است ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "پوشه گروه \"{mountPoint}\" تقریبا پر است ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "حافظه خارجی \"{mountPoint}\" تقریباً پر است ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "فضای ذخیره‌سازی شما تقریباً پر است ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["مطابقت با \"{filter}\"","مطابقت با \"{filter}\""],
    "View in folder" : "مشاهده در پوشه",
    "Path" : "مسیر",
    "_%n byte_::_%n bytes_" : ["%n بایت","%n بایت"],
    "Favorited" : "برگزیده شده",
    "Favorite" : "برگزیده",
    "New folder" : "پوشه جدید",
    "Create new folder" : "ساختن پوشه جدید",
    "Upload file" : "بارگذاری پرونده",
    "Recent" : "اخیر",
    "Not favorited" : "مورد علاقه نیست",
    "Remove from favorites" : "حذف کردن از برگزیده ها",
    "Add to favorites" : "اضافه کردن به برگزیده ها",
    "An error occurred while trying to update the tags" : "یک خطا در حین بروزرسانی برچسب‌ها رخ داده است",
    "Added to favorites" : "محبوب شد",
    "Removed from favorites" : "از محبوب‌ها حذف شد",
    "You added {file} to your favorites" : "شما پروندهٔ {file} را به مورد پسند‌هایتان افزودید",
    "You removed {file} from your favorites" : "شما پروندهٔ {file} را از مورد پسند‌های خود حذف کردید",
    "Favorites" : "موارد محبوب",
    "File changes" : "تغییرات پرونده",
    "Created by {user}" : "{user} ٖایجاد کرد",
    "Changed by {user}" : "{user} تغییر داد",
    "Deleted by {user}" : " {user} حذف کرد",
    "Restored by {user}" : "بازیابی شده توسط {user}",
    "Renamed by {user}" : "تغییر نام توسط {user}",
    "Moved by {user}" : "منتقل شده توسط {user}",
    "You created {file}" : "شما {file} را ایجاد کردید",
    "You created an encrypted file in {file}" : "شما یک فایل رمزگذاری شده در {file} ایجاد کردید",
    "{user} created {file}" : "{user} {file} را ایجاد کرد",
    "{user} created an encrypted file in {file}" : "{user} یک فایل رمزگذاری شده در {file} ایجاد کرد",
    "{file} was created in a public folder" : "{file} در یک پوشه عمومی ایجاد شد",
    "You changed {file}" : "شما {file} را تغییر دادید",
    "You changed an encrypted file in {file}" : "شما یک فایل رمزگذاری شده را در {file} تغییر دادید",
    "{user} changed {file}" : "{user} {file} را تغییر داد",
    "{user} changed an encrypted file in {file}" : "{user} یک فایل رمزگذاری شده را در {file} تغییر داد",
    "You deleted {file}" : "شما {file} را حذف کردید",
    "You deleted an encrypted file in {file}" : "شما یک فایل رمزگذاری شده را در {file} حذف کردید",
    "{user} deleted {file}" : "{user} {file} را حذف کرد",
    "{user} deleted an encrypted file in {file}" : "{user} یک فایل رمزگذاری شده را در {file} حذف کرد",
    "You restored {file}" : "شما {file} را بازیابی کردید",
    "{user} restored {file}" : "{user} {file} را بازیابی کرد",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "شما نام {oldfile} (پنهان) را به {newfile} (پنهان) تغییر دادید",
    "You renamed {oldfile} (hidden) to {newfile}" : "شما نام {oldfile} (پنهان) را به {newfile} تغییر دادید",
    "You renamed {oldfile} to {newfile} (hidden)" : "شما نام {oldfile} را به {newfile} تغییر دادید (پنهان)",
    "You renamed {oldfile} to {newfile}" : "شما نام {oldfile} را به {newfile} تغییر دادید",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} به {oldfile} تغییر نام داد (پنهان) به {newfile} (مخفی)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} به {oldfile} تغییر نام داد (پنهان) به {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} نام {oldfile} را به {newfile} تغییر داد (پنهان)",
    "{user} renamed {oldfile} to {newfile}" : "{user} نام {oldfile} را به {newfile} تغییر داد",
    "You moved {oldfile} to {newfile}" : "شما {oldfile} را به {newfile} منتقل کردید",
    "{user} moved {oldfile} to {newfile}" : "{user} {oldfile} را به {newfile} منتقل کرد",
    "A file has been added to or removed from your <strong>favorites</strong>" : "یک فایل به موارد دلخواه شما اضافه یا حذف شده است",
    "A file or folder has been <strong>changed</strong>" : "یک فایل یا پوشه تغییر کرده است",
    "A favorite file or folder has been <strong>changed</strong>" : "یک فایل یا پوشه مورد علاقه تغییر کرده است",
    "Upload (max. %s)" : "آپلود (بیشترین سایز %s)",
    "Accept" : "قبول",
    "Reject" : "رد کردن",
    "Incoming ownership transfer from {user}" : "انتقال مالکیت ورودی از {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "آیا می خواهید {path} را بپذیرید؟\n\nتوجه: فرآیند انتقال پس از پذیرش ممکن است تا 1 ساعت طول بکشد.",
    "Ownership transfer failed" : "انتقال مالکیت ناموفق بود",
    "Your ownership transfer of {path} to {user} failed." : "انتقال مالکیت شما از {path} به {user} انجام نشد.",
    "The ownership transfer of {path} from {user} failed." : "انتقال مالکیت {path} از {user} انجام نشد.",
    "Ownership transfer done" : "انتقال مالکیت انجام شد",
    "Your ownership transfer of {path} to {user} has completed." : "انتقال مالکیت شما از {path} به {user} تکمیل شد.",
    "The ownership transfer of {path} from {user} has completed." : "انتقال مالکیت {path} از {user} تکمیل شد.",
    "in %s" : "در %s",
    "File Management" : "مدیریت فایل",
    "Reload current directory" : "دایرکتوری فعلی را دوباره بارگیری کنید",
    "Go to the \"{dir}\" directory" : "به دایرکتوری \"{dir}\" بروید",
    "Drag and drop files here to upload" : "برای بارگذاری، فایل‌ها را بکشید و اینجا بیاندازید",
    "You don’t have permission to upload or create files here" : "شما دسترسی مجاز برای آپلود یا ایجاد فایل در اینجا را ندارید",
    "\"{displayName}\" action executed successfully" : "عملکرد \"{displayName}\" با موفقیت اجرا شد",
    "\"{displayName}\" action failed" : "اقدام \"{displayName}\" ناموفق بود",
    "Rename file" : "تغییر نام فایل",
    "Filename" : "نام پرونده",
    "Folder name" : "نام پوشه",
    "This node is unavailable" : "گره شما در دسترس نیست",
    "Renamed \"{oldName}\" to \"{newName}\"" : "تغییر نام \"{oldName}\" به \"{newName}\"",
    "Could not rename \"{oldName}\", it does not exist any more" : "نمی‌توان نام «{oldName}» را تغییر داد، دیگر وجود ندارد",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "نام \"{newName}\" در پوشه \"{dir}\" به کار رفته است.\nلطفا نام دیگری برگزینید.",
    "Could not rename \"{oldName}\"" : "تغییر نام \"{oldName}\" ممکن نیست",
    "Clear filter" : "پاک کردن پالایه",
    "Type" : "نوع",
    "Active filters" : "Active filters",
    "Remove filter" : "Remove filter",
    "Total rows summary" : "خلاصه کل ردیف ها",
    "\"{displayName}\" failed on some elements " : "\"{displayName}\" در برخی از عناصر ناموفق بود",
    "\"{displayName}\" batch action executed successfully" : "عملکرد دسته‌ای \"{displayName}\" با موفقیت اجرا شد",
    "List of files and folders." : "لیست فایل ها و پوشه ها",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "این لیست به دلایل عملکرد به طور کامل ارائه نشده است. در حین حرکت در لیست، فایل ها ارائه می شوند.",
    "File not found" : "فایل یافت نشد",
    "{usedQuotaByte} used" : "{usedQuotaByte} استفاده شده است",
    "{relative}% used" : "{نسبی}% استفاده شده است",
    "Could not refresh storage stats" : "نمی‌توان آمار ذخیره‌سازی را بازخوانی کرد",
    "Your storage is full, files can not be updated or synced anymore!" : "فضای ذخیره ی شما کاملا پر است، بیش از این فایلها بهنگام یا همگام سازی نمی توانند بشوند!",
    "Create" : "ساخت",
    "Submit" : "ارسال",
    "Transfer ownership of a file or folder" : "انتقال مالکیت یک فایل یا پوشه",
    "Choose file or folder to transfer" : "فایل یا پوشه را برای انتقال انتخاب کنید",
    "Change" : "تغییر",
    "New owner" : "مالک جدید",
    "Choose a file or folder to transfer" : "فایل یا پوشه ای را برای انتقال انتخاب کنید",
    "Transfer" : "انتقال",
    "Transfer {path} to {userid}" : "انتقال {path} به {userid}",
    "Invalid path selected" : "مسیر نامعتبر انتخاب شده است",
    "Unknown error" : "خطای نامشخص",
    "Ownership transfer request sent" : "درخواست انتقال مالکیت ارسال شد",
    "Cannot transfer ownership of a file or folder you do not own" : "نمی‌توان مالکیت فایل یا پوشه‌ای را که متعلق به شما نیست، منتقل کرد",
    "Select file or folder to link to" : "فایل یا پوشه را برای پیوند انتخاب کنید",
    "Choose {file}" : "انتخاب {file}",
    "Loading current folder" : "در حال بارگیری پوشه فعلی",
    "No files in here" : "هیچ فایلی اینجا وجود ندارد",
    "Upload some content or sync with your devices!" : "محتوایی را آپلود کنید یا با دستگاه خود همگام‌سازی کنید!",
    "Go to the previous folder" : "به پوشه قبلی بروید",
    "Go back" : "برگرد",
    "Share" : "اشتراک‌گذاری",
    "Shared by link" : "اشتراک گذاشته شده از طریق لینک",
    "Shared" : "به اشتراک گذاشته شده ",
    "Switch to list view" : "Switch to list view",
    "Upload was cancelled by user" : "آپلود توسط کاربر لغو شد",
    "Views" : "بازدیدها",
    "Files settings" : "تنظیمات پرونده‌ها",
    "File cannot be accessed" : "فایل قابل دسترسی نیست",
    "Open in files" : "Open in files",
    "Sort favorites first" : "ابتدا موارد دلخواه را مرتب کنید",
    "Show hidden files" : "نمایش پرونده‌های مخفی",
    "Crop image previews" : "پیش نمایش تصویر برش",
    "Additional settings" : "تنظیمات اضافی",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "کپی به کلیپ بورد",
    "Use this address to access your Files via WebDAV" : "از این آدرس برای دسترسی به فایل های خود از طریق WebDAV استفاده کنید",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "اگر 2FA را فعال کرده اید، باید با کلیک کردن در اینجا یک رمز عبور برنامه جدید ایجاد و استفاده کنید.",
    "Clipboard is not available" : "کلیپ بورد در دسترس نیست",
    "WebDAV URL copied to clipboard" : "URL WebDAV در کلیپ بورد کپی شد",
    "Unable to change the favourite state of the file" : "امکان تغییر حالت دلخواه فایل وجود ندارد",
    "Error while loading the file data" : "خطا هنگام بارگیری داده های فایل",
    "Pick a template for {name}" : "یک الگو برای {name} انتخاب کنید",
    "Create a new file with the selected template" : "یک فایل جدید با الگوی انتخاب شده ایجاد کنید",
    "Creating file" : "ایجاد فایل",
    "Blank" : "جای خالی",
    "Unable to create new file from template" : "امکان ایجاد فایل جدید از الگو وجود ندارد",
    "Delete permanently" : "حذف قطعی",
    "Delete files" : "Delete files",
    "Cancel" : "لغو",
    "Copy to {target}" : "رونوشت به {target}",
    "Move to {target}" : "جابجایی به {target}",
    "Open folder {displayName}" : "باز کردن پوشه {displayName}",
    "Open in Files" : "در فایل باز کنید",
    "Open details" : "باز کردن جزئیات",
    "Today" : "امروز",
    "Last 7 days" : "۷ روز گذشته",
    "Last 30 days" : "۳۰ روز گذشته",
    "Documents" : "سندها",
    "Audio" : "صدا",
    "Videos" : "فیلم ها ",
    "Unable to initialize the templates directory" : "راه اندازی دایرکتوری الگوها ممکن نیست",
    "Templates" : "قالب‌ها",
    "Some files could not be moved" : "برخی از پرونده‌ها قابل انتقال نیستند",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} پوشه","{folderCount} پوشه"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} پرونده","{fileCount} پرونده"],
    "List of favorites files and folders." : "لیست فایل ها و پوشه های مورد علاقه",
    "No favorites yet" : "هنوز مورد دلخواه وجود ندارد",
    "Files and folders you mark as favorite will show up here" : "فایل‌ها و پوشه‌های انتخاب شده به عنوان برگزیده توسط شما، در اینجا نمایش داده می‌شود",
    "All files" : "تمامی فایل‌ها",
    "List of recently modified files and folders." : "فهرست فایل‌ها و پوشه‌هایی که اخیراً اصلاح شده‌اند.",
    "No recently modified files" : "هیچ فایلی که اخیراً اصلاح شده است",
    "Files and folders you recently modified will show up here." : "فایل‌ها و پوشه‌هایی که اخیراً تغییر داده‌اید در اینجا نمایش داده می‌شوند.",
    "No entries found in this folder" : "هیچ ورودی‌ای در این پوشه وجود ندارد",
    "Select all" : "انتخاب همه",
    "Upload too large" : "سایز فایل برای آپلود زیاد است(م.تنظیمات در php.ini)",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "فایلها بیش از حد تعیین شده در این سرور هستند\nمترجم:با تغییر فایل php,ini میتوان این محدودیت را برطرف کرد",
    "Text file" : "فایل متنی",
    "New text file.txt" : "پروندهٔ متنی جدید با پسوند txt",
    "Direct link was copied (only works for users who have access to this file/folder)" : "پیوند مستقیم کپی شد (فقط برای کاربرانی که به این فایل/پوشه دسترسی دارند کار می کند)",
    "Copy direct link (only works for users who have access to this file/folder)" : "کپی لینک مستقیم (فقط برای کاربرانی که به این فایل/پوشه دسترسی دارند کار می کند)",
    "\"remote user\"" : "\"کاربران از راه‌ دور\"",
    "{newName} already exists." : "{newName} از قبل وجود دارد.",
    "Name cannot be empty" : "نام نمی‌تواند خالی باشد",
    "Another entry with the same name already exists" : "ورودی دیگری با همین نام در حال حاضر وجود دارد",
    "Storage informations" : "ذخیره سازی اطلاعات ",
    "Open the files app settings" : "تنظیمات برنامه فایل ها را باز کنید",
    "You might not have have permissions to view it, ask the sender to share it" : "ممکن است مجوز مشاهده آن را نداشته باشید، از فرستنده بخواهید آن را به اشتراک بگذارد",
    "Create new templates folder" : "پوشه قالب های جدید ایجاد کنید",
    "Toggle %1$s sublist" : "تغییر%1$s فهرست فرعی"
},
"nplurals=2; plural=(n > 1);");
